#include "adv3.h"
#ifdef __STDC__
int g010() 
#else
int g010() 
#endif
{ if (v007()) return 0; if (s006()) return 0; if (s007()) return 0; if (n007())
return 0; if (b005()) return 0; if (b006()) return 0; if (b007()) return
0; if (h009()) return 0; if (o008()) return 0; if (i004()) return 0; if
(u004()) return 0; if (t008()) return 0; if (t009()) return 0; if (d003())
return 0; if (g014()) return 0; if (z005()) return 0; if (l006()) return
0; if (n008()) return 0; if (o009()) return 0; if (l007()) return 0; if
(t010()) return 0; return 1; } 
#ifdef __STDC__
int g012() 
#else
int g012() 
#endif
{ if (v008()) return 0; if (v009()) return 0; return 1; } 
#ifdef __STDC__
int z006() 
#else
int z006() 
#endif
{ if (k003()) return 0; if (d004()) return 0; return 1; } 
#ifdef __STDC__
int y012() 
#else
int y012() 
#endif
{ if (x008()) return 0; if (j010()) return 0; return 1; } 
#ifdef __STDC__
int t011() 
#else
int t011() 
#endif
{ if (o011()) return 0; if (e009()) return 0; return 1; } 
#ifdef __STDC__
int o012() 
#else
int o012() 
#endif
{ if (o013()) return 0; if (k004()) return 0; return 1; } 
#ifdef __STDC__
int e010() 
#else
int e010() 
#endif
{ if (d005()) return 0; if (f009()) return 0; return 1; } 
#ifdef __STDC__
int b009() 
#else
int b009() 
#endif
{ if (y013()) return 0; if (h011()) return 0; if (n010()) return 0; return
1; } 
#ifdef __STDC__
int b011() 
#else
int b011() 
#endif
{ if (n011()) return 0; if (m004()) return 0; return 1; } 
#ifdef __STDC__
int c011() 
#else
int c011() 
#endif
{ if (t012()) return 0; if (c012()) return 0; if (x011()) return 0; return
1; } 
#ifdef __STDC__
int z008() 
#else
int z008() 
#endif
{ if (w008()) return 0; if (f010()) return 0; return 1; } 
#ifdef __STDC__
int x012() 
#else
int x012() 
#endif
{ if (n012()) return 0; if (v010()) return 0; return 1; } 
#ifdef __STDC__
int y014() 
#else
int y014() 
#endif
{ if (k005()) return 0; if (m005()) return 0; return 1; } 
#ifdef __STDC__
int n013() 
#else
int n013() 
#endif
{ if (y015()) return 0; if (t013()) return 0; return 1; } 
#ifdef __STDC__
int n015() 
#else
int n015() 
#endif
{ if (s010()) return 0; if (i006()) return 0; return 1; } 
#ifdef __STDC__
int l009() 
#else
int l009() 
#endif
{ if (q005()) return 0; if (u009()) return 0; return 1; } 
#ifdef __STDC__
int r013() 
#else
int r013() 
#endif
{ if (a010()) return 0; if (z009()) return 0; if (m007()) return 0; if (t017())
return 0; if (m008()) return 0; if (x016()) return 0; return 1; } 
#ifdef __STDC__
int z010() 
#else
int z010() 
#endif
{ if (d008()) return 0; if (k008()) return 0; return 1; } 
#ifdef __STDC__
int d010() 
#else
int d010() 
#endif
{ if (c014()) return 0; if (r015()) return 0; return 1; } 
#ifdef __STDC__
int d011() 
#else
int d011() 
#endif
{ if (o015()) return 0; if (l013()) return 0; return 1; } 
#ifdef __STDC__
int m010() 
#else
int m010() 
#endif
{ if (v013()) return 0; if (t018()) return 0; return 1; } 
#ifdef __STDC__
int d012() 
#else
int d012() 
#endif
{ if (k012()) return 0; if (r017()) return 0; if (n017()) return 0; return
1; } 
#ifdef __STDC__
int a011() 
#else
int a011() 
#endif
{ if (g017()) return 0; if (y019()) return 0; if (e013()) return 0; if (z011())
return 0; return 1; } 
#ifdef __STDC__
int v015() 
#else
int v015() 
#endif
{ if (k013()) return 0; if (v016()) return 0; return 1; } 
#ifdef __STDC__
int l014() 
#else
int l014() 
#endif
{ if (f015()) return 0; if (n018()) return 0; return 1; } 
#ifdef __STDC__
int b014() 
#else
int b014() 
#endif
{ if (c015()) return 0; if (i007()) return 0; return 1; } 
#ifdef __STDC__
int h014() 
#else
int h014() 
#endif
{ if (q008()) return 0; if (s013()) return 0; return 1; } 
#ifdef __STDC__
int t019() 
#else
int t019() 
#endif
{ if (i008()) return 0; if (x018()) return 0; return 1; } 
#ifdef __STDC__
int h015() 
#else
int h015() 
#endif
{ if (c016()) return 0; if (j016()) return 0; if (s014()) return 0; return
1; } 
#ifdef __STDC__
int v017() 
#else
int v017() 
#endif
{ if (y020()) return 0; if (n019()) return 0; return 1; } 
#ifdef __STDC__
int d014() 
#else
int d014() 
#endif
{ if (r018()) return 0; if (x020()) return 0; return 1; } 
#ifdef __STDC__
int y022() 
#else
int y022() 
#endif
{ if (h016()) return 0; if (e017()) return 0; return 1; } 
#ifdef __STDC__
int r020() 
#else
int r020() 
#endif
{ if (x021()) return 0; if (t021()) return 0; return 1; } 
#ifdef __STDC__
int y024() 
#else
int y024() 
#endif
{ if (q011()) return 0; if (v021()) return 0; return 1; } 
#ifdef __STDC__
int x023() 
#else
int x023() 
#endif
{ if (c020()) return 0; if (w018()) return 0; return 1; } 
#ifdef __STDC__
int t024() 
#else
int t024() 
#endif
{ if (a014()) return 0; if (u016()) return 0; return 1; } 
#ifdef __STDC__
int k018() 
#else
int k018() 
#endif
{ if (y025()) return 0; if (i012()) return 0; return 1; } 
#ifdef __STDC__
int r022() 
#else
int r022() 
#endif
{ if (g020()) return 0; if (j020()) return 0; return 1; } 
#ifdef __STDC__
int s019() 
#else
int s019() 
#endif
{ if (y029()) return 0; if (c025()) return 0; return 1; } 
#ifdef __STDC__
int h026() 
#else
int h026() 
#endif
{ if (i015()) return 0; if (e024()) return 0; return 1; } 
#ifdef __STDC__
int d022() 
#else
int d022() 
#endif
{ if (b017()) return 0; if (f020()) return 0; return 1; } 
#ifdef __STDC__
int d023() 
#else
int d023() 
#endif
{ if (j022()) return 0; if (v025()) return 0; return 1; } 
#ifdef __STDC__
int e026() 
#else
int e026() 
#endif
{ if (v026()) return 0; if (g024()) return 0; return 1; } 
#ifdef __STDC__
int q014() 
#else
int q014() 
#endif
{ if (c026()) return 0; if (j023()) return 0; return 1; } 
#ifdef __STDC__
int q015() 
#else
int q015() 
#endif
{ if (g025()) return 0; if (u020()) return 0; if (i016()) return 0; if (c027())
return 0; if (a019()) return 0; return 1; } 
#ifdef __STDC__
int u021() 
#else
int u021() 
#endif
{ if (o021()) return 0; if (y031()) return 0; return 1; } 
#ifdef __STDC__
int c028() 
#else
int c028() 
#endif
{ if (b018()) return 0; if (v027()) return 0; return 1; } 
#ifdef __STDC__
int y032() 
#else
int y032() 
#endif
{ if (q016()) return 0; if (k023()) return 0; if (h027()) return 0; return
1; } 
#ifdef __STDC__
int l024() 
#else
int l024() 
#endif
{ if (i018()) return 0; if (f022()) return 0; if (b019()) return 0; if (m016())
return 0; if (r025()) return 0; if (s022()) return 0; if (t032()) return
0; if (n026()) return 0; if (c029()) return 0; if (x026()) return 0; return
1; } 
#ifdef __STDC__
int h028() 
#else
int h028() 
#endif
{ if (u022()) return 0; if (a020()) return 0; return 1; } 
#ifdef __STDC__
int b020() 
#else
int b020() 
#endif
{ if (m017()) return 0; if (r026()) return 0; return 1; } 
#ifdef __STDC__
int o022() 
#else
int o022() 
#endif
{ if (o023()) return 0; if (x027()) return 0; if (m018()) return 0; if (g026())
return 0; return 1; } 
#ifdef __STDC__
int j024() 
#else
int j024() 
#endif
{ if (i020()) return 0; if (c031()) return 0; return 1; } 
#ifdef __STDC__
int s024() 
#else
int s024() 
#endif
{ if (m019()) return 0; if (o024()) return 0; return 1; } 
#ifdef __STDC__
int i021() 
#else
int i021() 
#endif
{ if (g027()) return 0; if (h029()) return 0; if (w021()) return 0; return
1; } 
#ifdef __STDC__
int j025() 
#else
int j025() 
#endif
{ if (n028()) return 0; if (h030()) return 0; return 1; } 
#ifdef __STDC__
int u023() 
#else
int u023() 
#endif
{ if (b022()) return 0; if (s026()) return 0; return 1; } 
#ifdef __STDC__
int x029() 
#else
int x029() 
#endif
{ if (k027()) return 0; if (i022()) return 0; return 1; } 
#ifdef __STDC__
int u024() 
#else
int u024() 
#endif
{ if (h031()) return 0; if (n029()) return 0; if (z015()) return 0; return
1; } 
#ifdef __STDC__
int t034() 
#else
int t034() 
#endif
{ if (e029()) return 0; if (i023()) return 0; if (m021()) return 0; return
1; } 
#ifdef __STDC__
int n030() 
#else
int n030() 
#endif
{ if (t035()) return 0; if (j028()) return 0; return 1; } 
#ifdef __STDC__
int h032() 
#else
int h032() 
#endif
{ if (m023()) return 0; if (u025()) return 0; return 1; } 
#ifdef __STDC__
int w025() 
#else
int w025() 
#endif
{ if (z016()) return 0; if (q018()) return 0; return 1; } 
#ifdef __STDC__
int i024() 
#else
int i024() 
#endif
{ if (v029()) return 0; if (q019()) return 0; return 1; } 
#ifdef __STDC__
int g029() 
#else
int g029() 
#endif
{ if (n033()) return 0; if (n034()) return 0; return 1; } 
#ifdef __STDC__
int z018() 
#else
int z018() 
#endif
{ if (j030()) return 0; if (g030()) return 0; return 1; } 
#ifdef __STDC__
int u026() 
#else
int u026() 
#endif
{ if (u027()) return 0; if (x031()) return 0; if (r028()) return 0; if (b025())
return 0; return 1; } 
#ifdef __STDC__
int m025() 
#else
int m025() 
#endif
{ if (c033()) return 0; if (w026()) return 0; if (x032()) return 0; if (z019())
return 0; if (n035()) return 0; return 1; } 
#ifdef __STDC__
int g033() 
#else
int g033() 
#endif
{ if (x033()) return 0; if (o025()) return 0; return 1; } 
#ifdef __STDC__
int v031() 
#else
int v031() 
#endif
{ if (t037()) return 0; if (s028()) return 0; if (r031()) return 0; return
1; } 
#ifdef __STDC__
int z020() 
#else
int z020() 
#endif
{ if (x034()) return 0; if (x035()) return 0; return 1; } 
#ifdef __STDC__
int x036() 
#else
int x036() 
#endif
{ if (u028()) return 0; if (x037()) return 0; return 1; } 
#ifdef __STDC__
int y036() 
#else
int y036() 
#endif
{ if (f027()) return 0; if (a023()) return 0; if (o026()) return 0; if (q022())
return 0; return 1; } 
#ifdef __STDC__
int u029() 
#else
int u029() 
#endif
{ if (h036()) return 0; if (h037()) return 0; if (n036()) return 0; return
1; } 
#ifdef __STDC__
int l027() 
#else
int l027() 
#endif
{ if (w027()) return 0; if (g035()) return 0; return 1; } 
#ifdef __STDC__
int c034() 
#else
int c034() 
#endif
{ if (e031()) return 0; if (o027()) return 0; return 1; } 
#ifdef __STDC__
int x038() 
#else
int x038() 
#endif
{ if (b026()) return 0; if (j032()) return 0; return 1; } 
#ifdef __STDC__
int c035() 
#else
int c035() 
#endif
{ if (b027()) return 0; if (m027()) return 0; return 1; } 
#ifdef __STDC__
int v006(void) 
#else
int v006() 
#endif
{return 0;} 
