#ifndef f006
#define f006
#define r008 "Adv550"
#define h001 "99.99"
#define h002 "Adv550 version September 18 1984"
#define f002 1
#ifndef t006
#define s005 "September 18 1984"
#define e004 "12.29.04, 10 Jan 2015"
#if defined(w004) || defined(_WIN32)
#define f007 "_adv550"
#else
#define f007 ".adv550"
#endif
#define o006 "adv550.dat"
#define y009 1
#define y010 1
#define h003 1
#define w005 3
#define w006 91
#define u003 92
#define h004 335
#define r009 336
#define x005 441
#define t007 442
#define g007 482
#define c007 482
#define g008 912
#define x006 19
#define z004 50
#define n004 425
#define m002 335
#define e005 442
#define q003 443
#define a009 446
#define c008 444
#define x007 445
#define r010 481
#define j007 3
#define h005 5
#define l004 0
#define e006 4
#define n005 336
#define h006 9999
#define j008 15
#define e007 13
#define i002 14
#define j009 3
#define l005 1
#define g009 2
#define h007 1
#define h008 0
#define n006 442
#define y011(X) (c005[444]==X || c005[445]==X)
#define e008 g010
#define g011 g012
#endif
#define o007 119726
#endif

