#if (defined(__cplusplus) || defined(z000)) && !defined(__STDC__)
#define __STDC__ 1
#endif
#ifdef a000
#define h000 f000
#endif
#define y000 '\377'
#define i000 '\376'
#define n000 '\375'
#define w000 '\373'
#define a001 '\372'
#define f001 '\371'
#define y001 '\370'
#define n001 '\367'
#define r000 '\366'
#define t000 '\365'
#define e000 '\364'
#define q000 '\363'
#if f002 >= 10
#ifdef o000
#define g000 '\362'
#endif 
#define r001 '\361'
#endif 
#define r002 '\360'
#define g001 '\357'
#ifdef FILE
#undef FILE
#endif
#include <stdio.h>
#include <setjmp.h>
#ifdef __STDC__
extern void f003 (int f004, int s000, int r003); extern int x000 (int a002);
extern void a003 (int a002, int t001); extern int g002 (int f004, int *b000);
extern int t002 (int q001, int i001, int u000); extern int a004 (int q001,
int i001, int u000, int z001); extern int s001 (int q001, int i001, int
u000); extern void b001 (int q001, int i001); extern void g003 (char s002,
int r004, char x001, int l000, int *v000, short *o001); extern void t003
(int q001, int i001); extern void j000 (int q001, int i001); extern void
y002 (int q001, int i001); extern void j001 (int q001, int i001); extern
int c000 (int q001, int *i001, short *u000); extern int e001 (int q001);
extern short *s003 (int j002); extern void w001 (int k000, char j002, int
j003, int y003, int *m000, short *c001); extern void g004 (char j002, int
j003, int y003); extern int r005 (int j002, int j003, int *y003, short *m000);
extern int y004 (int j002, int j003); extern void x002 (char z002); 
#ifdef READLINE
extern char *u001 (char *x003, int a005, int l001, int a006, int g005);
#else 
extern char *u001 (char *x003, int a005, int l001, int a006); 
#endif 
extern void g006 (void); extern int r006 (int d000); extern int u002 (int
q001, int i001, int u000); extern void n002 (void); extern void v001 (int
a002); extern void o002 (int f004, int a007, int type); extern void v002
(int b002, int s000, int e002, int z003); extern int t004 (int o003, ...);
extern int y005 (int o003, ...); extern void h000 (int j002, int j003, ...);
extern void f005 (int z003, int y006); extern int w002 (int t005); extern
void c002 (void); extern void d001 (int); extern int j004 (int); extern
int e002 (char *); extern void a008 (void); extern void c003 (void); extern
void k001 (void); extern int w003 (void); extern int b003 (void); extern
void l002 (void); extern int (*k002[])(void); extern void c004 (int); extern
int s004 (char *); extern void r007 (int, int *); extern void v003 (char
*); extern int y007 (char *, int); extern void m001 (char *, int); extern
char *j005 (char *); extern void v004 (void); extern void b004 (void); 
#ifdef __WIN32
extern void j006 (int); 
#endif 
#else 
extern void f003 (); extern int x000 (); extern void a003 (); extern int
g002 (); extern int t002 (); extern int a004 (); extern int s001 (); extern
void b001 (); extern void g003 (); extern void t003 (); extern void j000
(); extern void y002 (); extern void j001 (); extern int e001 (); extern
short *s003 (); extern void g004 (); extern int y004 (); extern void x002
(); extern char *u001 (); extern void g006 (); extern int r006 (); extern
int u002 (); extern void n002 (); extern void v001 (); extern void o002
(); extern void v002 (); extern int t004 (); extern int y005 (); extern
void h000 (); extern void f005 (); extern int w002 (); extern void c002
(); extern void d001 (); extern int j004 (); extern int e002(); extern void
a008(); extern void c003(); extern void k001(); extern int w003 (); extern
int b003 (); extern void l002 (); extern int (*k002[]) (); extern void c004
(); extern int s004 (); extern void r007 (); extern void v003 (); extern
int y007 (); extern void m001 (); extern char *j005 (); extern void v004
(); extern void b004 (); 
#ifdef __WIN32
extern void j006 (); 
#endif 
#endif 
extern jmp_buf q002; extern int *c005; extern int *n003; extern short *o004;
extern short *x004; extern short *e003; 
#define o005 "and"
#define d002 "then"
#include "adv1.h"
#ifdef c006
extern int l003; 
#endif 
extern int y008; 
